m4us.core.api — Message For You Sir! v0.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.1.1 documentation »
- API Documentation »

# `m4us.core.api`

Provides convenient access to all public core objects.

By providing this convenience in a separate module (`m4us.api`), instead of in the package root (`m4us`), projects working under tight memory constraints can reduce the memory footprint of this project by instead directly importing only those modules they need.

See also

m4us.core and the various core module documentation for details on the available objects in imported into this module.

### Navigation

- index
- modules |
- next |
- previous |
- Message For You Sir! v0.1.1 documentation »
- API Documentation »